=======
History
=======

0.1.2.2 (2019-04-07)
------------------
* Fixed broken assertions

0.1.2.1 (2019-04-07)
------------------
* New agents:
    - EmailSend
    - OnNewEmail
    - GetWalletReceiveAddress
    - OnWalletBalanceChange
    - WalletSend
    - AttributeDifference
    - NumberDifference
    - DeDuplicationDetector
    - DelayedEventQueue
    - RssChecker

0.1.1 (2019-02-08)
------------------
* First release on PyPI.
